@@ -9,6 +9,10 @@
 #' @param status_change_only If TRUE, returns only the dates marked
 #'     with a Recruitment Status change, default FALSE.
 #'
+#' @param polite If TRUE, this function uses the `polite` package to
+#'     download data, if FALSE, this function uses the `rvest`
+#'     package, default TRUE.
+#'
 #' @return A character vector of ISO-8601 formatted dates
 #'     corresponding to the dates on which there were clinical trial
 #'     history version updates.
@@ -19,13 +23,14 @@
 #'
 #' @examples
 #'
-#' \dontrun{
+#' \donttest{
 #' versions <- clinicaltrials_gov_dates("NCT00942747")
 #' }
 #'
 clinicaltrials_gov_dates <- function(
                                      nctid,
-                                     status_change_only=FALSE
+                                     status_change_only=FALSE,
+                                     polite=TRUE
                                      ) {
     out <- tryCatch({
 
@@ -52,9 +57,12 @@ clinicaltrials_gov_dates <- function(
             nctid
         )
 
-        session <- polite::bow(url)
-
-        index <- polite::scrape(session)
+        if (polite) {
+            session <- polite::bow(url)    
+            index <- polite::scrape(session)
+        } else {
+            index <- rvest::read_html(url)
+        }
 
         ## Back up locale info
         lct <- Sys.getlocale("LC_TIME")
